@@ -525,19 +525,23 @@ class JsonList(list):
 
     def to_dataframe(self, recursive: bool = False):
         from pandas import DataFrame
-        if issubclass(self.list_type, JsonObject):
-            if self.list_type is JsonObject:
-                if len(self) == 0:
-                    return DataFrame()
+        if self.list_type is JsonObject or self.list_type is None:
+            if len(self) == 0:
+                return DataFrame()
+            if isinstance(self[0], JsonObject):
                 columns = self[0].get_columns()
             else:
-                columns = self.list_type().get_columns()
-            if recursive:
-                return DataFrame([i.__dataframe_values__() for i in self], columns=columns)
-            else:
-                return DataFrame([i.get_values() for i in self], columns=columns)
+                raise RuntimeError("Item type cannot be loaded to dataframe")
         else:
-            return DataFrame(self)
+            if issubclass(self.list_type, JsonObject):
+                columns = self.list_type().get_columns()
+            else:
+                return DataFrame(self)
+
+        if recursive:
+            return DataFrame([i.__dataframe_values__() for i in self], columns=columns)
+        else:
+            return DataFrame([i.get_values() for i in self], columns=columns)
 
     def from_dataframe(self, df):
         self.clear()
